==> haskell-resourcet-1.2.1-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resourcet
version: 1.2.1
id: resourcet-1.2.1-9L77r2TmBqb6vPZxXVR5sr
key: resourcet-1.2.1-9L77r2TmBqb6vPZxXVR5sr
license: BSD-3-Clause
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.
category: Data, Conduit
abi: 70bafb0ab3a792c6dee7cee6abd3785b
exposed: True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource
import-dirs: /usr/lib/ghc-8.4.3/site-local/resourcet-1.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/resourcet-1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/resourcet-1.2.1
hs-libraries: HSresourcet-1.2.1-9L77r2TmBqb6vPZxXVR5sr
depends:
    base-4.11.1.0 containers-0.5.11.0 transformers-0.5.5.0 mtl-2.2.2
    exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8
    unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
             unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS=f455d126eaad42d9d326e7b0a54e0e51
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=a76404d2410541ab4c0cf63ee4e3a316
haddock-interfaces: /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html: /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resourcet-1.2.1-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resourcet
version: 1.2.1
id: resourcet-1.2.1-HIT1uiDVpcxDTEPc4WOeAH
key: resourcet-1.2.1-HIT1uiDVpcxDTEPc4WOeAH
license: BSD-3-Clause
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.
category: Data, Conduit
abi: 63beb88722f12bd2df4fa896ef9b7f12
exposed: True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource
import-dirs: /usr/lib/ghc-8.4.3/site-local/resourcet-1.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/resourcet-1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/resourcet-1.2.1
hs-libraries: HSresourcet-1.2.1-HIT1uiDVpcxDTEPc4WOeAH
depends:
    base-4.11.1.0 containers-0.5.11.0 transformers-0.5.5.0 mtl-2.2.2
    exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8
    unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
             unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS=f455d126eaad42d9d326e7b0a54e0e51
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=a76404d2410541ab4c0cf63ee4e3a316
haddock-interfaces: /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html: /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
